==> xlniuxdata_newGift-1.0.1-20160519.124336-3-sources.jar: com/xunlei/niux/data/newGift/vo/Gift.java <==
package com.xunlei.niux.data.newGift.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by zy on 2016/3/23.
 */
@Table(tableName="gift",pkFieldName="seqId",pkFieldAssign=false)
public class Gift {

    private Long seqId;
    private String giftName;
    private Long modelNo;
    private String advNo;
    private Integer monthTotal;
    private Integer weekTotal;
    private Integer dayTotal;
    private Integer total;
    private Integer frozenTotal;
    private Integer leftNm;
    private Integer orderNo;
    private String startTime;
    private String endTime;
    private String editTime;
    private String editBy;
    private Integer status;

    private Integer bonus;
    private String bonusType;
    private String actNo;

    public String getActNo() {
        return actNo;
    }

    public void setActNo(String actNo) {
        this.actNo = actNo;
    }

    public Integer getBonus() {
        return bonus;
    }

    public void setBonus(Integer bonus) {
        this.bonus = bonus;
    }

    public String getBonusType() {
        return bonusType;
    }

    public void setBonusType(String bonusType) {
        this.bonusType = bonusType;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getGiftName() {
        return giftName;
    }

    public void setGiftName(String giftName) {
        this.giftName = giftName;
    }

    public Long getModelNo() {
        return modelNo;
    }

    public void setModelNo(Long modelNo) {
        this.modelNo = modelNo;
    }

    public String getAdvNo() {
        return advNo;
    }

    public void setAdvNo(String advNo) {
        this.advNo = advNo;
    }

    public Integer getMonthTotal() {
        return monthTotal;
    }

    public void setMonthTotal(Integer monthTotal) {
        this.monthTotal = monthTotal;
    }

    public Integer getWeekTotal() {
        return weekTotal;
    }

    public void setWeekTotal(Integer weekTotal) {
        this.weekTotal = weekTotal;
    }

    public Integer getDayTotal() {
        return dayTotal;
    }

    public void setDayTotal(Integer dayTotal) {
        this.dayTotal = dayTotal;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public Integer getFrozenTotal() {
        return frozenTotal;
    }

    public void setFrozenTotal(Integer frozenTotal) {
        this.frozenTotal = frozenTotal;
    }

    public Integer getLeftNm() {
        return leftNm;
    }

    public void setLeftNm(Integer leftNm) {
        this.leftNm = leftNm;
    }

    public Integer getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(Integer orderNo) {
        this.orderNo = orderNo;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
}

==> xlniuxdata_newGift-1.0.2-20170111.080534-33-sources.jar: com/xunlei/niux/data/newGift/vo/Gift.java <==
package com.xunlei.niux.data.newGift.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by zy on 2016/3/23.
 */
@Table(tableName="gift",pkFieldName="seqId",pkFieldAssign=false)
public class Gift {

    private Long seqId;
    private String giftName;
    private Long modelNo;
    private String advNo;
    private Integer monthTotal;
    private Integer weekTotal;
    private Integer dayTotal;
    private Integer total;
    private Integer frozenTotal;
    private Integer leftNm;
    private Integer orderNo;
    private String startTime;
    private String endTime;
    private String editTime;
    private String editBy;
    private Integer status;

    private Integer bonus;
    private String bonusType;
    private String actNo;
    
    private String	thresholdType;
	private Float	threshold;

    public String getActNo() {
        return actNo;
    }

    public void setActNo(String actNo) {
        this.actNo = actNo;
    }

    public Integer getBonus() {
        return bonus;
    }

    public void setBonus(Integer bonus) {
        this.bonus = bonus;
    }

    public String getBonusType() {
        return bonusType;
    }

    public void setBonusType(String bonusType) {
        this.bonusType = bonusType;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getGiftName() {
        return giftName;
    }

    public void setGiftName(String giftName) {
        this.giftName = giftName;
    }

    public Long getModelNo() {
        return modelNo;
    }

    public void setModelNo(Long modelNo) {
        this.modelNo = modelNo;
    }

    public String getAdvNo() {
        return advNo;
    }

    public void setAdvNo(String advNo) {
        this.advNo = advNo;
    }

    public Integer getMonthTotal() {
        return monthTotal;
    }

    public void setMonthTotal(Integer monthTotal) {
        this.monthTotal = monthTotal;
    }

    public Integer getWeekTotal() {
        return weekTotal;
    }

    public void setWeekTotal(Integer weekTotal) {
        this.weekTotal = weekTotal;
    }

    public Integer getDayTotal() {
        return dayTotal;
    }

    public void setDayTotal(Integer dayTotal) {
        this.dayTotal = dayTotal;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public Integer getFrozenTotal() {
        return frozenTotal;
    }

    public void setFrozenTotal(Integer frozenTotal) {
        this.frozenTotal = frozenTotal;
    }

    public Integer getLeftNm() {
        return leftNm;
    }

    public void setLeftNm(Integer leftNm) {
        this.leftNm = leftNm;
    }

    public Integer getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(Integer orderNo) {
        this.orderNo = orderNo;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

	public String getThresholdType() {
		return thresholdType;
	}

	public void setThresholdType(String thresholdType) {
		this.thresholdType = thresholdType;
	}

	public Float getThreshold() {
		return threshold;
	}

	public void setThreshold(Float threshold) {
		this.threshold = threshold;
	}
}
